@@ -43,7 +43,6 @@ from twisted.internet import defer, reactor
 from twisted.web.client import HTTPConnectionPool
 
 from kiosk_client.job import Job
-from kiosk_client.utils import get_download_path
 from kiosk_client.utils import iter_image_files
 from kiosk_client.utils import sleep
 from kiosk_client.utils import strip_bucket_prefix
@@ -70,11 +69,7 @@ class JobManager(object):
         self.created_at = timeit.default_timer()
         self.all_jobs = []
 
-        host = str(host)
-        if not any(host.startswith(x) for x in ('http://', 'https://')):
-            host = 'http://{}'.format(host)
-
-        self.host = host
+        self.host = self._get_host(host)
         self.job_type = job_type
 
         model = kwargs.get('model', '')
@@ -131,6 +126,29 @@ class JobManager(object):
         self.pool.maxPersistentPerHost = settings.CONCURRENT_REQUESTS_PER_HOST
         self.pool.retryAutomatically = False
 
+    def _get_host(self, host):
+        """Send a GET request to the provided host. Check for redirects.
+
+        Twisted does not allow POST requests to follow redirects. Use requests
+        to send a single GET request to the host and follow any redirects.
+
+        Args:
+            host (str): The user-provided hostname.
+
+        Returns:
+            str: The hostname after all redirects.
+        """
+        host = str(host).lower()
+        if not any(host.startswith(x) for x in ('http://', 'https://')):
+            host = 'http://{}'.format(host)
+
+        try:
+            url = str(requests.get(host).url)
+            url = url[:-1] if url.endswith('/') else url
+            return url
+        except:
+            raise RuntimeError('Could not connect to host: %s' % host)
+
     def upload_file(self, filepath, acl='publicRead',
                     hash_filename=True, prefix=None):
         prefix = self.upload_prefix if prefix is None else prefix
@@ -162,6 +180,7 @@ class JobManager(object):
                    postprocess=self.postprocess,
                    upload_prefix=self.upload_prefix,
                    update_interval=self.update_interval,
+                   download_results=self.download_results,
                    expire_time=self.expire_time,
                    pool=self.pool)
 
@@ -223,18 +242,6 @@ class JobManager(object):
 
         yield self._stop()
 
-    def download_file_from_url(self, url, dest):
-        """Download a file from the URL to the destination file path."""
-        # TODO: resolve treq SSL issue, replace requests with treq.
-        start = timeit.default_timer()
-        self.logger.info('Downloading output file %s to %s.', url, dest)
-        with requests.get(url, stream=True) as r:
-            r.raise_for_status()
-            with open(dest, 'wb') as outfile:
-                shutil.copyfileobj(r.raw, outfile)
-        self.logger.info('Saved output file: "%s" in %s s.',
-                         dest, timeit.default_timer() - start)
-
     def summarize(self):
         time_elapsed = timeit.default_timer() - self.created_at
         self.logger.info('Finished %s jobs in %s seconds.',
@@ -264,17 +271,6 @@ class JobManager(object):
             len(self.all_jobs), self.start_delay, uuid.uuid4().hex)
         output_filepath = os.path.join(settings.OUTPUT_DIR, output_filepath)
 
-        if self.download_results:
-            for job in self.all_jobs:
-                try:
-                    basename = job.output_url.split('/')[-1]
-                    filepath = os.path.join(get_download_path(), basename)
-                    self.download_file_from_url(job.output_url, filepath)
-                except Exception as err:  # pylint: disable=broad-except
-                    self.logger.error('Could not download %s due to %s: %s. ',
-                                      job.output_url, type(err).__name__, err)
-                    continue
-
         with open(output_filepath, 'w') as jsonfile:
             json.dump(jsondata, jsonfile, indent=4)
             self.logger.info('Wrote job data as JSON to %s.', output_filepath)
